/*
 *  init.h - Initializing options.
 *
 *  Copyright (C) 2001, 2002
 *
 *  Neven Has <haski@sezampro.yu>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


#ifndef H_INIT_
#define H_INIT_

/*
 * Some program's info.
 */
#define EMAIL              "haski@sezampro.yu"
#define SITE               "http://www.linuxfromscratch.org/alfs/"
#define COPYRIGHT          "Copyright (C) 2001-2003 Neven Has"

void read_env_variables(void);

void read_system_rc_file(void);
void read_user_rc_file(void);

void read_command_line_options(int *argc, char ***argv);

void init_needed_directories(void);


#endif /* H_INIT_ */
